function [nfmt,fmt]=three_tube_model_pt3(vm,fileout,rL,rG,l1,l2,l3,A1,A2,A3)

% inputs:  
%   vm: three-tube model log magnitude frequency response in steps of 1 Hz
%   fileout: name of file for writing formant frequency and bandwidth
%   rL=lip impedance
%   rG=glottal impedance 
%   l1=length of section 1
%   l2=length of section 2 
%   l3=length of section 3
%   A1=area of section 1 
%   A2=area of section 2
%   A3=area of section 3
%
% outputs:
%   nfmt: number of formants
%   fmt: set of formant frequencies

% find formant (resonance) locations and bandwidths
        fmt=[];
        nfmt=0;
        for freq=1:1:4998
            if (vm(freq+1) > vm(freq) && vm(freq+1) > vm(freq+2) )
                fmt=[fmt freq];
                nfmt=nfmt+1;
            end
        end
       
% find formant bandwidth by finding pair of frequencies (one above resonance,
% one below resonance) where log magnitude response is peakl (6) dB 
% below resonance peak
    bwlevel=6; %(db)level below formant peak for defining formant bandwidth
        for nf=1:nfmt
            f=fmt(nf);
            peak=vm(f+1);
            [peakl,peakh]=findpeak(vm,f,peak,bwlevel);
            fr(nf)=f;
            bw(nf)=peakh-peakl;
        end
        
%
% print out input parameters and sets of resonance frequency and bandwidth
%
        fname=strcat(fileout,'.txt');
        fid=fopen(fname,'a');
        fprintf(fid,'3-tube vocal tract model results: \n');
        fprintf(fid,'l1,A1,l2,A2,l3,A3: %4.1f %4.1f %4.1f %4.1f %4.1f %4.1f \n',...
            l1,A1,l2,A2,l3,A3);
        fprintf(fid,'rL,rG: %4.1f %4.1f \n',rL,rG);
        for formant=1:nfmt
            fprintf(fid,'formant frequency: %d, formant bandwidth: %d \n',...
                fr(formant),bw(formant));
        end
        fprintf(fid,'\n \n');
end